///File : strWxStdConv.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "strWxStdConv.hpp"
//------------------------------------------------------------------------------
wxString wxStrAutoCut(wxString str, const int &maxLen)
{
    if(str.Len() > maxLen)
    {
        str = str.Mid(0, maxLen - 3);
        str << _T("...");
    }

    return str;
}
//------------------------------------------------------------------------------
std::string StrWxToStd(const wxString &str)
{
	return std::string(str.mb_str(wxConvUTF8));
}
//------------------------------------------------------------------------------
wxString StrStdToWx(const std::string &str)
{
	return wxString(str.c_str(), wxConvUTF8);
}
//------------------------------------------------------------------------------
// Filename
std::string filenameWxToStd(const wxString &str)
{
	return std::string(str.mb_str(wxConvFile));
}
//------------------------------------------------------------------------------
wxString filenameStdToWx(const std::string &str)
{
	return wxString(str.c_str(), wxConvFile);
}
//------------------------------------------------------------------------------
wxFont stdFontToWxFont(const StructStdFont &font)
{
    int fontStyle = wxFONTSTYLE_NORMAL;
    if(font.italic)
    {
        fontStyle = wxFONTSTYLE_ITALIC;
    }

    wxFontWeight fontWeight = wxFONTWEIGHT_NORMAL;
    if(font.bold)
    {
        fontWeight = wxFONTWEIGHT_BOLD;
    }

    wxFont newFont(font.pointSize, wxFONTFAMILY_DEFAULT, fontStyle, fontWeight, font.underligned, StrStdToWx(font.faceName));
    return newFont;
}
//------------------------------------------------------------------------------
StructStdFont wxFontToStdFont(const wxFont &font)
{
    StructStdFont newFont;
    newFont.bold = font.GetWeight() == wxFONTWEIGHT_BOLD;
    newFont.faceName = StrWxToStd(font.GetFaceName());
    newFont.italic = font.GetStyle() == wxFONTSTYLE_ITALIC;
    newFont.pointSize = font.GetPointSize();
    newFont.underligned = font.GetUnderlined();
    return newFont;
}
//------------------------------------------------------------------------------
wxColour stdColorToWxColor(const StructStdColor &color)
{
    wxColour newColour(color.r, color.g, color.b);
    return newColour;
}
//------------------------------------------------------------------------------
StructStdColor wxColorToStdColor(const wxColour &color)
{
    StructStdColor newColour = {color.Red(), color.Green(), color.Blue()};
    return newColour;
}
//------------------------------------------------------------------------------
// ColorFont
StructWxColorFont stdColorFontToWxColorFont(const StructStdColorFont &colorFont)
{
    StructWxColorFont data;

    data.wxcolor = stdColorToWxColor(colorFont.color);
    data.wxfont = stdFontToWxFont(colorFont.font);

    return data;
}
//------------------------------------------------------------------------------
StructStdColorFont wxColorFontToStdColorFont(const StructWxColorFont &colorFont)
{
    StructStdColorFont data;

    data.color = wxColorToStdColor(colorFont.wxcolor);
    data.font = wxFontToStdFont(colorFont.wxfont);

    return data;
}
//------------------------------------------------------------------------------
